# Slot: generation_date


date and time that the schema was loaded/generated

URI: [http://w3id.org/biolink/biolinkml/meta/generation_date](slot_uri)
## Domain and Range

[SchemaDefinition](SchemaDefinition.md) -><sub>opt</sub> [Datetime](Datetime.md)
## Inheritance

## Children

## Used by

 * [SchemaDefinition](SchemaDefinition.md)
